#!/bin/sh

# This helper script will handle deploying an activemq broker
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

## Undeclared Dependencies (see 'helm/templates/_activemq.yaml')
## - 'brokerName' originates from the inputsInEnvName ConfigMap that is mounted to the deploy/destroy jobs.
## - 'TF_VAR_broker_password' is an explicit k8s env variable declared on the deploy/destroy jobs.

if [ -z "${brokerName}" ]; then
  echo "Must set env brokerName"
  exit 1
fi

check_access ${appsNamespace} configmaps

terraform_init
terraform_plan
terraform_apply
terraform_output

## ConfigMap: ARN
## ---------------------
print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get id idValue

cat >/tmp/${arnConfigMapName}.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  id: ${idValue}
EOF

run_cmd cat "/tmp/${arnConfigMapName}.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/${arnConfigMapName}.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/${arnConfigMapName}.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

## END: ConfigMap: ARN
## ---------------------


## ConfigMap: Endpoint
## ---------------------
print_header "Dump endpoints to ConfigMap"
endpointConfigMapName=${namingPrefix}-endpoint

## ConfigMap: -endpoint
## ---------------------
cat >/tmp/${endpointConfigMapName}.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${endpointConfigMapName}
data:
  amqp: $(cat output.json | jq .endpoints.value.amqp)
  console: $(cat output.json | jq .endpoints.value.console)
  mqtt: $(cat output.json | jq .endpoints.value.mqtt)
  openwire: $(cat output.json | jq .endpoints.value.openwire)
  stomp: $(cat output.json | jq .endpoints.value.stomp)
  ws: $(cat output.json | jq .endpoints.value.ws)
EOF

run_cmd cat "/tmp/${endpointConfigMapName}.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/${endpointConfigMapName}.yaml

echo "Config map ${endpointConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${endpointConfigMapName} -o yaml

cprint "$0 done "

## END: ConfigMap: Endpoint
## ---------------------
