#!/bin/bash

# This helper script will handle generation of a db primary password for both apps and infra namespaces
#
# /scripts/gen-primary-secret.sh
#

set -e

source /scripts/utils.sh

check_access ${infraNamespace} secrets
check_access ${appsNamespace} secrets

echo "Creating kubernetes secret ${brokerUserCredsSecretUserName}"
create_secret_user ${brokerUserCredsSecretUserName} ${infraNamespace} ${namingPrefix}
create_secret_user ${brokerUserCredsSecretUserName} ${appsNamespace} ${namingPrefix}

echo "Generating new password."

## See https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/getting-started-activemq.html
# The following restrictions apply to broker usernames and passwords:
#   - Your username can contain only alphanumeric characters, dashes, periods, underscores, and tildas (- . _ ~).
#   - Your password must be at least 12 characters long, contain at least 4 unique characters and must not
#     contain commas, colons, or equal signs (,:=).
password=$(openssl rand -hex 24)

create_secret_password ${brokerUserCredsSecretPassName} ${infraNamespace} ${password}
create_secret_password ${brokerUserCredsSecretPassName} ${appsNamespace} ${password}

print_header "$0 done."

